# dsnd-distributions package
- Gaussian distribution for calculating and visualizing a Gaussian distribution.
- Binomial distribution for calculating and visualizing a Binomial distribution.

# installation
- pip install dsnd-probability-rvs

# example using
- gaussian = Gaussian(25, 3)
- gaussian.read_data_file('numbers.txt')
- binomial = Binomial(0.4, 20)
- binomial.read_data_file('numbers_binomial.txt')
